"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SESMock = void 0;
const typescript_helper_functions_1 = require("typescript-helper-functions");
// tslint:disable-next-line: no-var-requires
const AWS = require('aws-sdk');
/**
 * SES Mock class
 */
class SESMock extends typescript_helper_functions_1.BaseMock {
    constructor() {
        super(...arguments);
        /**
         * Mocks an AWS.SES.SendEmailResponse response
         */
        this.SendEmailResponse = { MessageId: 'message-id' };
    }
    /**
     * Create the SES mock
     */
    CreateMock(returnError) {
        const rejectResponse = new Error(`AWS Error`);
        // implement the AWS responses
        const awsResponses = {
            // send email response
            sendEmail: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.SendEmailResponse);
                }),
            },
        };
        // create the functions
        let functions = new AWS.SES();
        functions = {
            sendEmail: () => awsResponses.sendEmail,
        };
        return functions;
    }
}
exports.SESMock = SESMock;
//# sourceMappingURL=mock.js.map